CREATE TABLE ATTRIBUTE (ATTRIBUTE_ID BIGINT NOT NULL, FLAGS BIGINT, NAME VARCHAR(255), TYPE INTEGER, VALUE CLOB, PRIMARY KEY (ATTRIBUTE_ID));
CREATE TABLE BASE (BASE_ID BIGINT NOT NULL, COMMENT CLOB, CUSTOM_DATA BLOB, DESCRIPTION CLOB, DTYPE VARCHAR(31), ENVIRONMENT_NAME VARCHAR(255), FOREIGN_ID BIGINT, INDEX INTEGER, NAME VARCHAR(1024), SOURCE_PROVIDER_ID BIGINT, SPECIFICATION CLOB, STATE_1 BIGINT, STATE_2 BIGINT, STATE_3 BIGINT, TIME_STAMP BIGINT, PRIMARY KEY (BASE_ID));
CREATE TABLE DOCUMENT_PART (DOCUMENT_PART_ID BIGINT NOT NULL, BASE_ID BIGINT, DTYPE VARCHAR(31), HAS_CHILDREN SMALLINT DEFAULT 0, PARENT_DOCUMENT_ID BIGINT, PROJECT_ID BIGINT, TESTRESULT_ID BIGINT, PRIMARY KEY (DOCUMENT_PART_ID));
CREATE TABLE PROJECT (PROJECT_ID BIGINT NOT NULL, BASE_ID BIGINT, PRIMARY KEY (PROJECT_ID));
CREATE TABLE PROVIDER_ATTRIBUTE (ATTRIBUTE_ID BIGINT NOT NULL, BASE_ID BIGINT NOT NULL, PRIMARY KEY (ATTRIBUTE_ID, BASE_ID));
CREATE TABLE SEQUENCE (SEQ_NAME VARCHAR(50) NOT NULL, SEQ_COUNT DECIMAL(15), PRIMARY KEY (SEQ_NAME));
CREATE TABLE SOURCE (SOURCE_ID BIGINT NOT NULL, DEFINES CLOB, FLAGS BIGINT, INCLUDES CLOB, INDEX INTEGER, NAME VARCHAR(255), OPTIONS CLOB, SOURCE_PROVIDER BIGINT, PRIMARY KEY (SOURCE_ID));
CREATE TABLE SOURCE_PROVIDER (SOURCE_PROVIDER_ID BIGINT NOT NULL, NEXT_SOURCE_INDEX INTEGER, PRIMARY KEY (SOURCE_PROVIDER_ID));
CREATE TABLE TESTITEM (TESTITEM_BASE_ID BIGINT NOT NULL, BASE_ID BIGINT, DTYPE VARCHAR(31), HAS_CHILDREN SMALLINT DEFAULT 0, PARENT_TESTITEM_ID BIGINT, REPEAT_COUNT INTEGER, SCENARIO_CODE BLOB, TESTCASE_NUMBER INTEGER, TESTITEM_TYPE INTEGER, TESTOBJECT_TESTITEM_ID BIGINT, PRIMARY KEY (TESTITEM_BASE_ID));
CREATE TABLE TESTOBJECT (TESTOBJECT_ID BIGINT NOT NULL, ACTIVE_TRESTRUN_ID BIGINT, BASE_ID BIGINT, FMODULE_DOCUMENT_PART_ID BIGINT, MODULE_ID BIGINT, NEXT_TESTCASE_NUMBER INTEGER, TESTOBJECT_TESTITEM_ID BIGINT, TESTOBJECT_TYPE INTEGER, TESTRESULT_ID BIGINT, PRIMARY KEY (TESTOBJECT_ID));
CREATE TABLE TESTRESULT (TESTRESULT_ID BIGINT NOT NULL, C0_ENABLED SMALLINT DEFAULT 0, C0_PASSED SMALLINT DEFAULT 0, C1_ENABLED SMALLINT DEFAULT 0, C1_PASSED SMALLINT DEFAULT 0, CALLTRACE_RESULT SMALLINT DEFAULT 0, COMPLETE SMALLINT DEFAULT 0, EVALMACRO_RESULT SMALLINT DEFAULT 0, MCC_ENABLED SMALLINT DEFAULT 0, MCC_PASSED SMALLINT DEFAULT 0, MCDC_ENABLED SMALLINT DEFAULT 0, MCDC_PASSED SMALLINT DEFAULT 0, MIN_C1_COVARAGE INTEGER, MIN_MCC_COVARAGE INTEGER, MIN_MCDC_COVARAGE INTEGER, NUMBER_BRANCHES BIGINT, NUMBER_MCC_COMBINATIONS BIGINT, NUMBER_MCDC_COMBINATIONS BIGINT, NUMBER_STATEMENTS BIGINT, PASSED SMALLINT DEFAULT 0, REACHED_BRANCHES BIGINT, REACHED_MCC_COMBINATIONS BIGINT, REACHED_MCDC_COMBINATIONS BIGINT, REACHED_STATEMENTS BIGINT, TESTCASES_FAILED INTEGER, TESTCASES_NOTEXECUTED INTEGER, TESTCASES_PASSED INTEGER, TESTCASES_TOTAL INTEGER, TESTDATA_RESULT SMALLINT DEFAULT 0, PRIMARY KEY (TESTRESULT_ID));
CREATE TABLE TESTRUN (TESTRUN_ID BIGINT NOT NULL, BASE_ID BIGINT, CREATED DATE, TESTOBJECT_ID BIGINT, TESTRESULT_ID BIGINT, PRIMARY KEY (TESTRUN_ID));
CREATE TABLE VERSION (MAJOR INTEGER NOT NULL, MINOR INTEGER NOT NULL, PRIMARY KEY (MAJOR, MINOR));

ALTER TABLE BASE ADD CONSTRAINT BSESURCEPROVIDERID FOREIGN KEY (SOURCE_PROVIDER_ID) REFERENCES SOURCE_PROVIDER (SOURCE_PROVIDER_ID);
ALTER TABLE DOCUMENT_PART ADD CONSTRAINT DCMENTPARTPRJECTID FOREIGN KEY (PROJECT_ID) REFERENCES PROJECT (PROJECT_ID);
ALTER TABLE DOCUMENT_PART ADD CONSTRAINT DCMNTPARTTSTRSLTID FOREIGN KEY (TESTRESULT_ID) REFERENCES TESTRESULT (TESTRESULT_ID);
ALTER TABLE DOCUMENT_PART ADD CONSTRAINT DCMNTPRTPRNTDCMNTD FOREIGN KEY (PARENT_DOCUMENT_ID) REFERENCES DOCUMENT_PART (DOCUMENT_PART_ID);
ALTER TABLE DOCUMENT_PART ADD CONSTRAINT DOCUMENTPARTBASEID FOREIGN KEY (BASE_ID) REFERENCES BASE (BASE_ID);
ALTER TABLE PROJECT ADD CONSTRAINT FK_PROJECT_BASE_ID FOREIGN KEY (BASE_ID) REFERENCES BASE (BASE_ID);
ALTER TABLE PROVIDER_ATTRIBUTE ADD CONSTRAINT PRVDERATTRIBUTEBSD FOREIGN KEY (BASE_ID) REFERENCES BASE (BASE_ID);
ALTER TABLE PROVIDER_ATTRIBUTE ADD CONSTRAINT PRVDRTTRBUTETTRBTD FOREIGN KEY (ATTRIBUTE_ID) REFERENCES ATTRIBUTE (ATTRIBUTE_ID);
ALTER TABLE SOURCE ADD CONSTRAINT SURCESURCEPROVIDER FOREIGN KEY (SOURCE_PROVIDER) REFERENCES SOURCE_PROVIDER (SOURCE_PROVIDER_ID);
ALTER TABLE TESTITEM ADD CONSTRAINT TESTITEM_BASE_ID FOREIGN KEY (BASE_ID) REFERENCES BASE (BASE_ID);
ALTER TABLE TESTITEM ADD CONSTRAINT TSTTMPRNTTSTITEMID FOREIGN KEY (PARENT_TESTITEM_ID) REFERENCES TESTITEM (TESTITEM_BASE_ID);
ALTER TABLE TESTOBJECT ADD CONSTRAINT TESTOBJECTMODULEID FOREIGN KEY (MODULE_ID) REFERENCES DOCUMENT_PART (DOCUMENT_PART_ID);
ALTER TABLE TESTOBJECT ADD CONSTRAINT TESTOBJECT_BASE_ID FOREIGN KEY (BASE_ID) REFERENCES BASE (BASE_ID);
ALTER TABLE TESTOBJECT ADD CONSTRAINT TSTBJECTTSTRSULTID FOREIGN KEY (TESTRESULT_ID) REFERENCES TESTRESULT (TESTRESULT_ID);
ALTER TABLE TESTOBJECT ADD CONSTRAINT TSTBJFMDLDCMNTPRTD FOREIGN KEY (FMODULE_DOCUMENT_PART_ID) REFERENCES DOCUMENT_PART (DOCUMENT_PART_ID);
ALTER TABLE TESTOBJECT ADD CONSTRAINT TSTBJTSTBJCTTSTTMD FOREIGN KEY (TESTOBJECT_TESTITEM_ID) REFERENCES TESTITEM (TESTITEM_BASE_ID);
ALTER TABLE TESTRUN ADD CONSTRAINT FK_TESTRUN_BASE_ID FOREIGN KEY (BASE_ID) REFERENCES BASE (BASE_ID);
ALTER TABLE TESTRUN ADD CONSTRAINT TSTRUNTESTOBJECTID FOREIGN KEY (TESTOBJECT_ID) REFERENCES TESTOBJECT (TESTOBJECT_ID);
ALTER TABLE TESTRUN ADD CONSTRAINT TSTRUNTESTRESULTID FOREIGN KEY (TESTRESULT_ID) REFERENCES TESTRESULT (TESTRESULT_ID);

INSERT INTO SEQUENCE(SEQ_NAME, SEQ_COUNT) values ('SEQ_GEN', 0);

CREATE TABLE TESSY_DATABASE (VERSION INT NOT NULL);
INSERT INTO TESSY_DATABASE (VERSION) VALUES (1);